# Git Phoenix

[![forthebadge](https://forthebadge.com/images/badges/made-with-python.svg)](https://forthebadge.com) [![Open Source Love](https://badges.frapsoft.com/os/v2/open-source.svg?v=103)](https://github.com/ellerbrock/open-source-badges/)

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://github.com/victoraugustofd/git-phoenix/blob/master/LICENSE) [![python: 3.6+](https://img.shields.io/badge/python-3.6+-blue)](https://www.python.org/download/releases/3.6.0/) [![Join the chat at https://gitter.im/git-phoenix/community](https://badges.gitter.im/git-phoenix/community.svg)](https://gitter.im/git-phoenix/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

[![CircleCI](https://circleci.com/gh/victoraugustofd/git-phoenix.svg?style=svg)](https://circleci.com/gh/victoraugustofd/git-phoenix) [![codecov.io](https://codecov.io/gh/victoraugustofd/git-phoenix/coverage.svg?branch=master)](https://codecov.io/gh/victoraugustofd/git-phoenix)

<p align="center">
  <img src="https://user-images.githubusercontent.com/21197980/46575862-31a46400-c994-11e8-9006-1ade4bc720cb.png" alt="phoenix">
</p>

## A dynamic Git Branching Tool

Git Phoenix is a Dynamic Branching Tool. We noticed that not all projects can be managed, using the branching models that are largely used by several companies. Many of them, have to adapt the way that they work with Git, just to fit with the branching model chosen.

Git Phoenix is exactly the opposite.

We made a system that adapts itself with the rules defined by the user or company, instead of the user or company adapt themselves to the system.

You can define the branching rules for your Git Repository on a JSON template.
